==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/ObjectSetIDs.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.ext;
using com.db4o.query;
namespace com.db4o.test {

   public class ObjectSetIDs {
      
      public ObjectSetIDs() : base() {
      }
      static internal int COUNT = 11;
      
      public void store() {
         Tester.deleteAllInstances(this);
         for (int i1 = 0; i1 < COUNT; i1++) {
            Tester.store(new ObjectSetIDs());
         }
      }
      
      public void test() {
         ExtObjectContainer con1 = Tester.objectContainer();
         Query q1 = Tester.query();
         q1.constrain(j4o.lang.Class.getClassForObject(this));
         ObjectSet res1 = q1.execute();
         long[] ids11 = new long[res1.size()];
         int i1 = 0;
         while (res1.hasNext()) {
            ids11[i1++] = con1.getID(res1.next());
         }
         res1.reset();
         long[] ids21 = res1.ext().getIDs();
         Tester.ensure(ids11.Length == COUNT);
         Tester.ensure(ids21.Length == COUNT);
         for (int j1 = 0; j1 < ids11.Length; j1++) {
            bool found1 = false;
            for (int k1 = 0; k1 < ids21.Length; k1++) {
               if (ids11[j1] == ids21[k1]) {
                  found1 = true;
                  break;
               }
            }
            Tester.ensure(found1);
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/ObjectSetIDs.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.ext;
using com.db4o.query;
namespace com.db4o.test {

   public class ObjectSetIDs {
      
      public ObjectSetIDs() : base() {
      }
      static internal int COUNT = 11;
      
      public void Store() {
         Tester.DeleteAllInstances(this);
         for (int i1 = 0; i1 < COUNT; i1++) {
            Tester.Store(new ObjectSetIDs());
         }
      }
      
      public void Test() {
         ExtObjectContainer con1 = Tester.ObjectContainer();
         Query q1 = Tester.Query();
         q1.Constrain(j4o.lang.Class.GetClassForObject(this));
         ObjectSet res1 = q1.Execute();
         long[] ids11 = new long[res1.Size()];
         int i1 = 0;
         while (res1.HasNext()) {
            ids11[i1++] = con1.GetID(res1.Next());
         }
         res1.Reset();
         long[] ids21 = res1.Ext().GetIDs();
         Tester.Ensure(ids11.Length == COUNT);
         Tester.Ensure(ids21.Length == COUNT);
         for (int j1 = 0; j1 < ids11.Length; j1++) {
            bool found1 = false;
            for (int k1 = 0; k1 < ids21.Length; k1++) {
               if (ids11[j1] == ids21[k1]) {
                  found1 = true;
                  break;
               }
            }
            Tester.Ensure(found1);
         }
      }
   }
}
